@@ -4,7 +4,7 @@ pub mod ffi {
         include!("wrapper/include/ro_mol.h");
         include!("wrapper/include/fingerprint.h");
 
-        pub type ROMol = crate::ro_mol::ffi::ROMol;
+        pub type ROMol = crate::ro_mol_ffi::ROMol;
         pub type ExplicitBitVect;
         pub fn fingerprint_mol(mol: SharedPtr<ROMol>) -> SharedPtr<ExplicitBitVect>;
 
