@@ -4,12 +4,13 @@ pub mod ffi {
         include!("wrapper/include/ro_mol.h");
         include!("wrapper/include/mol_standardize.h");
 
-        pub type ROMol = crate::ro_mol::ffi::ROMol;
-        pub type RWMol = crate::rw_mol::ffi::RWMol;
+        pub type ROMol = crate::ro_mol_ffi::ROMol;
+        pub type RWMol = crate::rw_mol_ffi::RWMol;
 
         pub type TautomerEnumerator;
         pub type TautomerEnumeratorResult;
         pub type CleanupParameters;
+        pub type Uncharger;
 
         pub fn tautomer_enumerator() -> SharedPtr<TautomerEnumerator>;
 
@@ -23,13 +24,23 @@ pub mod ffi {
             tautomer_enumerator_result: SharedPtr<TautomerEnumeratorResult>,
         ) -> SharedPtr<ROMol>;
 
+        pub fn tautomer_enumerator_result_tautomers_size(enumerator_result: SharedPtr<TautomerEnumeratorResult>) -> i32;
+        pub fn tautomer_enumerator_result_tautomers_at(enumerator_result: SharedPtr<TautomerEnumeratorResult>, at: usize) -> SharedPtr<ROMol>;
+
         pub fn default_cleanup_parameters() -> SharedPtr<CleanupParameters>;
 
+        pub fn new_uncharger(canonical: bool) -> SharedPtr<Uncharger>;
+        pub fn uncharger_uncharge(uncharger: SharedPtr<Uncharger>, mol: SharedPtr<RWMol>) -> SharedPtr<RWMol>;
+
         pub fn fragment_parent(
             rw_mol: SharedPtr<RWMol>,
             cleanup_params: SharedPtr<CleanupParameters>,
             skip_standardize: bool,
         ) -> SharedPtr<RWMol>;
 
+        pub fn normalize(
+            rw_mol: SharedPtr<RWMol>,
+            cleanup_params: SharedPtr<CleanupParameters>
+        ) -> SharedPtr<RWMol>;
     }
 }
