@@ -4,7 +4,7 @@ pub mod ffi {
         include!("wrapper/include/ro_mol.h");
 
         pub type ROMol;
-        pub type ExplicitBitVect = crate::fingerprint::ffi::ExplicitBitVect;
+        pub type ExplicitBitVect = crate::fingerprint_ffi::ExplicitBitVect;
 
         pub fn mol_from_smiles(smi: &CxxString) -> SharedPtr<ROMol>;
         pub fn mol_to_smiles(mol: SharedPtr<ROMol>) -> String;
